#!/bin/bash

####
## the following lines should be changed to your local settings
##
# this is the path to the top-level of the repository
ROOT=~/Omega/Papers/2013-Apr-AllTrees/Repository
# this is the location of bob edgar's qscore program, http://drive5.com/qscore/
QSCORE=/usr/local/bin/qscore
# alistat - show some simple statistics on an alignment file, SQUID 1.9g (Oct 2002)
ALISTAT=/usr/local/bin/alistat
# Clustal-Omega is needed for distance calculation
CLUSTALO=/usr/local/bin/clustalo
MAFFT=/usr/local/bin/mafft
LINSI=/usr/local/bin/linsi
MUSCLE=/usr/local/bin/muscle
PAGAN=/usr/local/bin/pagan
##
## no more changes should be necessary beyond this line
####


USAGE="2 arguments expected: (1) aligner, (2) number of sequences\npossible numbers of sequences 4,5,6,7,8,16\npossible aligners clustalo, muscle, mafft, linsi, pagan"
if [ $# -ne 2 ]; then
	echo -e $USAGE
	exit
else
	LEAVES=$2
	aligner=$1
fi
echo "you selected "$aligner" and "$LEAVES


# these are sub-directories of the repository
SEQUENCES=$ROOT/Homstrad
TREES=$ROOT/Trees
ALIGN=$ROOT/Align
TOOLS=$ROOT/Tools


if [ $LEAVES -eq 4 ]; then
	UNLABELED=2
elif [ $LEAVES -eq 5 ]; then
	UNLABELED=3
elif [ $LEAVES -eq 6 ]; then
	UNLABELED=6
elif [ $LEAVES -eq 7 ]; then
	UNLABELED=11
elif [ $LEAVES -eq 8 ]; then
	UNLABELED=23
elif [ $LEAVES -eq 16 ]; then
	UNLABELED=101 # this is only a small sample
else 
	echo "don't know how to process "$LEAVES" sequences, only possibilities 4,5,6,7,8,16"
	exit
fi


if [ $aligner == "clustalo" ]; then
	ALIGNER=$CLUSTALO
	VERSION=$($ALIGNER --long-version)
elif [ $aligner == "muscle" ]; then
	ALIGNER=$MUSCLE
	VERSION=$($ALIGNER -version)
elif [ $aligner == "mafft" ]; then 
	ALIGNER=$MAFFT
	VERSION=$($ALIGNER -version 2> /dev/stdout | grep MAFFT)
elif [ $aligner == "linsi" ] ; then
	ALIGNER=$LINSI
    	VERSION=$($ALIGNER -version 2> /dev/stdout | grep MAFFT)
elif [ $aligner == "pagan" ]; then
	ALIGNER=$PAGAN
	VERSION=$($ALIGNER --version | grep PAGAN)
else
	echo "unknown aligner "$aligner
	exit
fi


#for vie in $SEQUENCES/$LEAVES/*.vie; do
for vie in $SEQUENCES/$LEAVES/r*_aadh.vie $SEQUENCES/$LEAVES/r*_aat.vie $SEQUENCES/$LEAVES/r*_ace.vie; do

	base=$(basename $vie .vie)
	dir=$(dirname $vie)
	ref=$dir/$base.ref
	RESULT=$aligner-$LEAVES-$base.dat

	echo -e "# Note:\taligner "$aligner >  $RESULT
	echo -e "# Note:\tversion "$VERSION >> $RESULT
	echo -e "# Note:\tfamily "$base" , "$LEAVES" sequences , "$UNLABELED" topologies" >> $RESULT
	echo -e "# Note:\t1.tree, 2.tree-ID, 3.TC-score, 4.SP-score, 5.alignment-length, 6.average-identity" >> $RESULT


	awk '{print $1}' $vie > infile

	$CLUSTALO -i infile -o outfile --force --full --distmat-out=distfile

	for u in `seq 1 $UNLABELED`; do

		while read tree; do

			echo $tree";" > tree
			if [ $aligner == "muscle" ] || [ $aligner == "mafft" ] || [ $aligner == "linsi" ] || [ $aligner == "pagan" ]; then
				$TOOLS/xTSP distfile tree _tree > /dev/null
				mv _tree tree
			fi
			if [ $aligner == "mafft" ] || [ $aligner == "linsi" ]; then
				$TOOLS/newick2mafft.rb tree > _tree 2> /dev/null
				mv _tree tree
			fi
			rm -f outfile
			if [ $aligner == "clustalo" ]; then
			    $ALIGNER -i infile -o outfile --force --guidetree-in=tree
			elif [ $aligner == "muscle" ]; then
			    $ALIGNER -in infile -out outfile -maxiters 1 -usetree tree > /dev/null 2> /dev/null
			elif [ $aligner == "mafft" ] || [ $aligner == "linsi" ]; then
			    $ALIGNER --anysymbol --thread 1 --treein tree infile > outfile 2> /dev/null
			elif [ $aligner == "pagan" ]; then
			    $ALIGNER --seqfile infile --outfile outfile --treefile tree --threads 1 > /dev/null 2> /dev/null
			    mv outfile.fas outfile
			fi

			qs=$($QSCORE -test outfile -ref $ref)
			tc=$(echo $qs | awk -F'[=;]' '{print $(NF)}')
			sp=$(echo $qs | awk -F'[=;]' '{print $(NF-2)}')

			$ALISTAT outfile > alistat.aux
			len=$(awk '/Alignment\ length/ {print $NF}' alistat.aux)
			pid=$(awk '/Average\ identity/ {print $NF}' alistat.aux)

			echo -e $tree"\t"$u"\t"$tc"\t"$sp"\t"$len"\t"$pid >> $RESULT
		done < $TREES/$LEAVES/labeled-$u.dat

	done # went through topologically distinct trees

	rm -f infile outfile alistat.aux distfile tree

#	break
done # went through sequences