#!/bin/bash



####
## the following lines should be changed to your local settings
##
# this is the path to the top-level of the repository
ROOT=~/Omega/Papers/2013-Apr-AllTrees/Repository
# this is the location of bob edgar's qscore program, http://drive5.com/qscore/
QSCORE=/usr/local/bin/qscore
# alistat - show some simple statistics on an alignment file, SQUID 1.9g (Oct 2002)
ALISTAT=/usr/local/bin/alistat
# Clustal-Omega is needed for distance calculation
CLUSTALO=/usr/local/bin/clustalo
MAFFT=/usr/local/bin/mafft
LINSI=/usr/local/bin/linsi
MUSCLE=/usr/local/bin/muscle
PAGAN=/usr/local/bin/pagan
##
## no more changes should be necessary beyond this line
####

# these are sub-directories of the repository
SEQUENCES=$ROOT/Homstrad
TREES=$ROOT/RAxML
ALIGN=$ROOT/Align
TOOLS=$ROOT/Tools
LEAVES=8

USAGE="1 argument expected: (1) aligner\npossible aligners clustalo, muscle, mafft, linsi, pagan"
if [ $# -ne 1 ]; then
        echo -e $USAGE
        exit
else
        aligner=$1
fi
echo "you selected "$aligner" and "$LEAVES


if [ $aligner == "clustalo" ]; then
        ALIGNER=$CLUSTALO
        VERSION=$($ALIGNER --long-version)
elif [ $aligner == "muscle" ]; then
        ALIGNER=$MUSCLE
        VERSION=$($ALIGNER -version)
elif [ $aligner == "mafft" ]; then 
        ALIGNER=$MAFFT
        VERSION=$($ALIGNER -version 2> /dev/stdout | grep MAFFT)
elif [ $aligner == "linsi" ] ; then
        ALIGNER=$LINSI
        VERSION=$($ALIGNER -version 2> /dev/stdout | grep MAFFT)
elif [ $aligner == "pagan" ]; then
        ALIGNER=$PAGAN
        VERSION=$($ALIGNER --version | grep PAGAN)
else
        echo "unknown aligner "$aligner
        exit
fi


RESULT1=$aligner-$LEAVES-raxml-scores.DAT
echo -e "#1.tree\t\t\t\t2.ID\t3.TC\t4.SP\t5.len\t6.pid\t7.fam" > $RESULT1
RESULT2=$aligner-$LEAVES-raxml-default.DAT
echo -e "#1.tree\t\t\t\t2.ID\t3.TC\t4.SP\t5.len\t6.pid\t7.fam" > $RESULT2

while read line; do

	if [[ $line == \#* ]]; then 
		continue
	else 
		tree=$(echo $line | awk '{print $1}')
		echo $tree";" > tree
		fam=$(echo $line | awk '{print $NF}')
		vie=$SEQUENCES/$LEAVES/$fam.vie
		ref=$SEQUENCES/$LEAVES/$fam.ref
		u=$(echo $line | awk '{print $2}')
	fi
	echo -e $tree"\t"$fam

	
	awk '{print $1}' $vie > infile
	$CLUSTALO -i infile -o outfile --force --full --distmat-out=distfile

	if [ $aligner == "muscle" ] || [ $aligner == "mafft" ] || [ $aligner == "linsi" ] || [ $aligner == "pagan" ]; then
	    	$TOOLS/xTSP distfile tree _tree > /dev/null
		mv _tree tree
	fi
	if [ $aligner == "mafft" ] || [ $aligner == "linsi" ]; then
	    	$TOOLS/newick2mafft.rb tree > _tree 2> /dev/null
		mv _tree tree
	fi
	rm -f outfile
	if [ $aligner == "clustalo" ]; then
	    	$ALIGNER -i infile -o outfile --force --guidetree-in=tree
	elif [ $aligner == "muscle" ]; then
	    	$ALIGNER -in infile -out outfile -maxiters 1 -usetree tree > /dev/null 2> /dev/null
	elif [ $aligner == "mafft" ] || [ $aligner == "linsi" ]; then
	    	$ALIGNER --anysymbol --thread 1 --treein tree infile > outfile 2> /dev/null
	elif [ $aligner == "pagan" ]; then
	    	$ALIGNER --seqfile infile --outfile outfile --treefile tree --threads 1 > /dev/null 2> /dev/null
		mv outfile.fas outfile
	fi

	qs=$($QSCORE -test outfile -ref $ref)
	tc=$(echo $qs | awk -F'[=;]' '{print $(NF)}')
	sp=$(echo $qs | awk -F'[=;]' '{print $(NF-2)}')
	
	$ALISTAT outfile > alistat.aux
	len=$(awk '/Alignment\ length/ {print $NF}' alistat.aux)
	pid=$(awk '/Average\ identity/ {print $NF}' alistat.aux)
	
	echo -e $tree"\t"$u"\t"$tc"\t"$sp"\t"$len"\t"$pid"\t"$fam >> $RESULT1

	###############################################

	if [ $aligner == "mafft" ] || [ $aligner == "linsi" ]; then
	    	$ALIGNER --anysymbol --thread 1 --retree 0 --treeout infile > outfile 2> /dev/null
		cat infile.tree | tr -d '\n' | sed 's/:[0-9\.]*//g' | sed 's/;//g' | sed 's/_[0-9]//g' > tree
		rm infile.tree
	elif [ $aligner == "muscle" ]; then
		$ALIGNER -in infile -out outfile -maxiters 1 -tree1 _tree > /dev/null 2> /dev/null
		cat _tree | tr -d '\n' | sed 's/:[0-9\.]*//g' | sed 's/;//g' > tree
	fi
	if [ $aligner == "muscle" ] || [ $aligner == "mafft" ] || [ $aligner == "linsi" ] || [ $aligner == "pagan" ]; then
	    	$TOOLS/xTSP distfile tree _tree > /dev/null
		mv _tree tree
	fi
	if [ $aligner == "mafft" ] || [ $aligner == "linsi" ]; then
	    	$TOOLS/newick2mafft.rb tree > _tree 2> /dev/null
		mv _tree tree
	fi
	rm -f outfile
	if [ $aligner == "clustalo" ]; then
	    	$ALIGNER -i infile -o outfile --force --guidetree-in=tree
	elif [ $aligner == "muscle" ]; then
	    	$ALIGNER -in infile -out outfile -maxiters 1 -usetree tree > /dev/null 2> /dev/null
	elif [ $aligner == "mafft" ] || [ $aligner == "linsi" ]; then
	    	$ALIGNER --anysymbol --thread 1 --treein tree infile > outfile 2> /dev/null
	elif [ $aligner == "pagan" ]; then
		continue
	fi

	qs=$($QSCORE -test outfile -ref $ref)
	tc=$(echo $qs | awk -F'[=;]' '{print $(NF)}')
	sp=$(echo $qs | awk -F'[=;]' '{print $(NF-2)}')
	
	$ALISTAT outfile > alistat.aux
	len=$(awk '/Alignment\ length/ {print $NF}' alistat.aux)
	pid=$(awk '/Average\ identity/ {print $NF}' alistat.aux)
	
	echo -e $tree"\t"$u"\t"$tc"\t"$sp"\t"$len"\t"$pid"\t"$fam >> $RESULT2

break

done < $TREES/raxml-trees.dat

rm -f infile outfile alistat.aux distfile tree
